#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sisio.h>

void vainsah( inbuf, inlen, outbuf, outlen )

	char *	inbuf;
	int *	inlen;
	char *	outbuf;
	int *	outlen;

{
	int	start, number, length, perword, ier;

	memcpy( outbuf + 0, inbuf + 0, 4);
	CTOHL( outbuf + 0, 1 );
	memcpy( outbuf + 4, inbuf + 4, 4);
	memcpy( outbuf + 8, inbuf + 8, 24);
	CTOHL( outbuf + 8, 6 );
	memcpy( outbuf + 32, inbuf + 32, 8);
	CTOHS( outbuf + 32, 4 );
	memcpy( outbuf + 40, inbuf + 40, 4);
	CTOHL( outbuf + 40, 1 );
	memcpy( outbuf + 44, inbuf + 44, 12);
	CTOHS( outbuf + 44, 6 );
	memcpy( outbuf + 56, inbuf + 56, 4);
	memcpy( outbuf + 60, inbuf + 60, 4);
	CTOHS( outbuf + 60, 2 );
	number = *inlen - 64;
	memcpy( outbuf + 64, inbuf + 64, number);
	CTOHF( outbuf + 64, number / 4 );
	*outlen = 64 + ( *inlen - 64 );
}
